% fi-thesis-report.sty
% LaTeX style for theses reports at FI MU
% Released to public domain.
% Feel free to contribute or add bug reports in the form of issues
% in the project's repository at https://gitlab.fi.muni.cz/xukrop/fi-thesis-report/
\ProvidesClass{fi-thesis-report}[2016/05/30 v0.8]

% Based on 'article'
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions \relax
\LoadClass[12pt]{article}

% Load necessary packages
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage[a4paper, top=30mm, bottom=35mm, left=30mm, right=30mm]{geometry}
\RequirePackage[final,kerning=true,spacing=true]{microtype}
\RequirePackage[czech]{babel}
\RequirePackage{graphicx}
\RequirePackage{tabularx}
\RequirePackage{tikz}
\RequirePackage{charter}
\usetikzlibrary{positioning}

% Define name strings and setting commands
\def\@student{}
\newcommand{\setStudent}[1]{\def\@student{#1}}
\def\@thesisName{}
\newcommand{\setThesisName}[1]{\def\@thesisName{#1}}
\def\@supervisor{}
\newcommand{\setSupervisor}[1]{\def\@supervisor{#1}}
\def\@reader{}
\newcommand{\setReader}[1]{\def\@reader{#1}}

% Document header (logo + table with names)
\AtBeginDocument{
\begin{tikzpicture}[remember picture,overlay]
\node[] (A) at (current page.north west) {};
\node[anchor=north west](FI-stitok) [below right=-3mm and 11.5mm of A] {\includegraphics{fi-stitok}};

\node[] (B) at (current page.north east) {};
\node[below left=14.3mm and 27mm of B](posudek){{\large \textsc{Posudek oponenta}}};
\node[below=4.9mm of posudek.east,anchor=east]{{\large \textsc{bakalářské práce}}};
\end{tikzpicture}
\medskip

\noindent
{\def\arraystretch{1.3}\tabcolsep=10pt
\begin{tabularx}{\textwidth}{@{} >{\bfseries} l l @{}}
Název práce: & \@thesisName \\
Autor práce: & \@student \\
Vedoucí práce: & \@supervisor \\
Oponent: & \@reader \\
\end{tabularx}
}
\vspace{0.6cm}
\@afterindentfalse\@afterheading
}

% Document footer (date, signature)
\AtEndDocument{
\vspace{3em}
\noindent
Brno \today \hfill \@reader
}
